@@ -6,8 +6,7 @@ from django.contrib.admin.options import BaseModelAdmin
 from django.contrib.auth.models import Permission, User
 from django.utils import timezone
 
-from data_browser import orm_fields
-from data_browser.orm_admin import get_models
+from data_browser.orm_admin import OrmModel, get_models
 from data_browser.orm_results import admin_get_queryset, get_results
 from data_browser.query import BoundQuery, Query
 
@@ -308,6 +307,16 @@ def test_get_is_null_function(get_product_flat):
     assert data == [["a", "NotNull"], ["b", "NotNull"], ["c", "IsNull"]]
 
 
+def test_get_aggregated_is_null_function(get_product_flat):
+    a = models.Producer.objects.create()
+    b = models.Producer.objects.create()
+    models.Product.objects.create(producer=a)
+    models.Product.objects.create(producer=b)
+    models.Product.objects.create(producer=b)
+    data = get_product_flat(1, "producer__id__is_null,id__count", {})
+    assert data == [["NotNull", 3]]
+
+
 @pytest.mark.usefixtures("products")
 def test_get_aggregate(get_product_flat):
     data = get_product_flat(1, "size_unit,id__count", {})
@@ -695,13 +704,13 @@ class TestPermissions:
         )
 
         assert "core.NotInAdmin" not in orm_models
-        assert orm_models["core.InAdmin"] == orm_fields.OrmModel(
+        assert orm_models["core.InAdmin"] == OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
-        assert orm_models["core.InlineAdmin"] == orm_fields.OrmModel(
+        assert orm_models["core.InlineAdmin"] == OrmModel(
             fields=KEYS("id", "name", "in_admin"), admin=ANY(BaseModelAdmin)
         )
-        assert orm_models["core.Normal"] == orm_fields.OrmModel(
+        assert orm_models["core.Normal"] == OrmModel(
             fields=KEYS("admin", "id", "name", "in_admin", "inline_admin"),
             admin=ANY(BaseModelAdmin),
         )
@@ -713,7 +722,7 @@ class TestPermissions:
         assert "core.NotInAdmin" not in orm_models
         assert "core.InAdmin" not in orm_models
         assert "core.InlineAdmin" not in orm_models
-        assert orm_models["core.Normal"] == orm_fields.OrmModel(
+        assert orm_models["core.Normal"] == OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
 
@@ -724,7 +733,7 @@ class TestPermissions:
         assert "core.NotInAdmin" not in orm_models
         assert "core.InAdmin" not in orm_models
         assert "core.InlineAdmin" not in orm_models
-        assert orm_models["core.Normal"] == orm_fields.OrmModel(
+        assert orm_models["core.Normal"] == OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
 
@@ -733,11 +742,11 @@ class TestPermissions:
         orm_models = self.get_fields_with_perms(rf, ["normal", "inadmin"])
 
         assert "core.NotInAdmin" not in orm_models
-        assert orm_models["core.InAdmin"] == orm_fields.OrmModel(
+        assert orm_models["core.InAdmin"] == OrmModel(
             fields=KEYS("admin", "id", "name"), admin=ANY(BaseModelAdmin)
         )
         assert "core.InlineAdmin" not in orm_models
-        assert orm_models["core.Normal"] == orm_fields.OrmModel(
+        assert orm_models["core.Normal"] == OrmModel(
             fields=KEYS("admin", "id", "name", "in_admin"), admin=ANY(BaseModelAdmin)
         )
 
@@ -873,3 +882,24 @@ def test_number_choice_field(get_product_flat):
         1, f"number_choice__raw", {"number_choice__raw__equals": [1]}
     )
     assert data == [[1]]
+
+
+def test_is_null_variants(get_product_flat):
+    producer = models.Producer.objects.create()
+    models.Product.objects.create(producer=producer, size=1, onsale=True)
+    models.Product.objects.create(producer=producer, size=2, onsale=None)
+
+    assert get_product_flat(1, "onsale__is_null,size+1", {}) == [
+        ["NotNull", 1],
+        ["IsNull", 2],
+    ]
+
+    # __is_null=
+    assert get_product_flat(1, "size", {"onsale__is_null": ["NotNull"]}) == [[1]]
+    assert get_product_flat(1, "size", {"onsale__is_null": ["IsNull"]}) == [[2]]
+
+    # __is_null__equals=
+    assert get_product_flat(1, "size", {"onsale__is_null__equals": ["NotNull"]}) == [
+        [1]
+    ]
+    assert get_product_flat(1, "size", {"onsale__is_null__equals": ["IsNull"]}) == [[2]]
