@@ -16,15 +16,12 @@ from data_browser.types import (
     DurationType,
     HTMLType,
     IsNullType,
-    MonthType,
     NumberChoiceType,
     NumberType,
     StringArrayType,
     StringChoiceType,
     StringType,
     UnknownType,
-    WeekDayType,
-    YearType,
 )
 
 from .util import ANY
@@ -48,7 +45,7 @@ def orm_models():
     return {
         "string": OrmModel(get_fields_for_type(StringType)),
         "number": OrmModel(get_fields_for_type(NumberType)),
-        "app.model": orm_fields.OrmModel(
+        "app.model": OrmModel(
             fields={
                 "fa": orm_fields.OrmConcreteField(
                     model_name="app.model",
@@ -94,7 +91,7 @@ def orm_models():
             },
             admin=True,
         ),
-        "app.Tom": orm_fields.OrmModel(
+        "app.Tom": OrmModel(
             fields={
                 "jones": orm_fields.OrmConcreteField(
                     model_name="app.Tom",
@@ -113,7 +110,7 @@ def orm_models():
             },
             admin=True,
         ),
-        "app.Michael": orm_fields.OrmModel(
+        "app.Michael": OrmModel(
             fields={
                 "bolton": orm_fields.OrmConcreteField(
                     model_name="app.Michael",
@@ -343,23 +340,6 @@ class TestNumberType:
         assert NumberType.get_formatter(None)(None) is None
 
 
-class TestYearType:
-    def test_validate(self):
-        assert YearType.parse("gt", "6", None) == (6, None)
-        assert YearType.parse("pontains", "6.1", None) == (None, ANY(str))
-        assert YearType.parse("gt", "hello", None) == (None, ANY(str))
-        assert YearType.parse("is_null", "IsNull", None) == (True, None)
-        assert YearType.parse("is_null", "hello", None) == (None, ANY(str))
-        assert YearType.parse("equals", "0", None) == (None, ANY(str))
-
-    def test_default_lookup(self):
-        assert YearType.default_lookup == "equals"
-
-    def test_format(self):
-        assert YearType.get_formatter(None)(6) == 6
-        assert YearType.get_formatter(None)(None) is None
-
-
 class TestDateTimeType:
     def test_validate(self):
         assert DateTimeType.parse("gt", "2018-03-20T22:31:23", None) == (
@@ -375,11 +355,36 @@ class TestDateTimeType:
         assert DateTimeType.parse("is_null", "hello", None) == (None, ANY(str))
         assert DateTimeType.parse("gt", "now", None) == (ANY(datetime), None)
 
+        assert DateTimeType.parse("gt", "11-11-2018", None) == (ANY(datetime), None)
         assert DateTimeType.parse("gt", "11-22-2018", None) == (ANY(datetime), None)
         assert DateTimeType.parse("gt", "21-12-2018", None) == (ANY(datetime), None)
         assert DateTimeType.parse("gt", "11-12-2018", None) == (None, ANY(str))
         assert DateTimeType.parse("gt", "21-22-2018", None) == (None, ANY(str))
 
+        assert DateTimeType.parse("gt", "2018-11-11", None) == (ANY(datetime), None)
+        assert DateTimeType.parse("gt", "2018-11-22", None) == (ANY(datetime), None)
+        assert DateTimeType.parse("gt", "2018-21-12", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "2018-11-12", None) == (ANY(datetime), None)
+        assert DateTimeType.parse("gt", "2018-21-22", None) == (None, ANY(str))
+
+        assert DateTimeType.parse("gt", "20181111", None) == (ANY(datetime), None)
+        assert DateTimeType.parse("gt", "20181122", None) == (ANY(datetime), None)
+        assert DateTimeType.parse("gt", "20182112", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "20181112", None) == (ANY(datetime), None)
+        assert DateTimeType.parse("gt", "20182122", None) == (None, ANY(str))
+
+        assert DateTimeType.parse("gt", "181111", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "181122", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "182112", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "181112", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "182122", None) == (None, ANY(str))
+
+        assert DateTimeType.parse("gt", "111118", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "112218", None) == (ANY(datetime), None)
+        assert DateTimeType.parse("gt", "211218", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "111218", None) == (None, ANY(str))
+        assert DateTimeType.parse("gt", "212218", None) == (None, ANY(str))
+
     def test_default_lookup(self):
         assert DateTimeType.default_lookup == "equals"
 
@@ -453,38 +458,6 @@ class TestDateType:
         assert DateType.get_formatter(None)(None) is None
 
 
-class TestWeekDayType:
-    def test_validate(self):
-        assert WeekDayType.parse("equals", "Sunday", None) == (1, None)
-        assert WeekDayType.parse("equals", "Saturday", None) == (7, None)
-        assert WeekDayType.parse("equals", "Bob", None) == (None, ANY(str))
-        assert WeekDayType.parse("gt", "Monday", None) == (None, ANY(str))
-
-    def test_format(self):
-        assert WeekDayType.get_formatter(None)(1) == "Sunday"
-        assert WeekDayType.get_formatter(None)(7) == "Saturday"
-        assert WeekDayType.get_formatter(None)(None) is None
-
-    def test_default_lookup(self):
-        assert WeekDayType.default_lookup == "equals"
-
-
-class TestMonthType:
-    def test_validate(self):
-        assert MonthType.parse("equals", "January", None) == (1, None)
-        assert MonthType.parse("equals", "December", None) == (12, None)
-        assert MonthType.parse("equals", "Bob", None) == (None, ANY(str))
-        assert MonthType.parse("gt", "January", None) == (None, ANY(str))
-
-    def test_format(self):
-        assert MonthType.get_formatter(None)(1) == "January"
-        assert MonthType.get_formatter(None)(12) == "December"
-        assert MonthType.get_formatter(None)(None) is None
-
-    def test_default_lookup(self):
-        assert MonthType.default_lookup == "equals"
-
-
 class TestBooleanType:
     def test_validate(self):
         assert BooleanType.parse("equals", "True", None) == (True, None)
@@ -538,7 +511,7 @@ class TestIsNullType:
     def test_format(self):
         assert IsNullType.get_formatter(IsNullType.choices)(True) == "IsNull"
         assert IsNullType.get_formatter(IsNullType.choices)(False) == "NotNull"
-        assert IsNullType.get_formatter(IsNullType.choices)(None) is None
+        assert IsNullType.get_formatter(IsNullType.choices)(None) == "IsNull"
 
     def test_validate(self):
         assert IsNullType.parse("equals", "IsNull", IsNullType.choices) == (True, None)
